import sys
sys.path.append('.')




if __name__ == '__main__':
    import menus

    fc = menus.FastCommand('Example Fast Command 5', type='FILES', command='cd ? & mkdir hello', command_vars=['DIR'])
    fc.compile()



# all imports ---------------
import os
import ctypes
import sys
from enum import Enum


# registry_shortcuts.py ----------------------------------------------------------------------------------------

try:
    import winreg

    # ------------------------------------------------------------------

    def is_admin():
        '''
        Returns True if the current python instance has admin, and false otherwise.
        '''
        try:
            return ctypes.windll.shell32.IsUserAnAdmin()
        except:
            return False

    def run_admin(params=sys.argv[0], force=False):
        '''
        If the python instance does not have admin priviledges, it stops the current execution and runs the program as admin.

        You can customize where it runs/Force it to run regardless.
        '''
        if not is_admin() or force:
            ctypes.windll.shell32.ShellExecuteW(
                None, "runas", sys.executable, params, None, 1)
            sys.exit()

    # ------------------------------------------------------------------

    def create_key(path: str, hive=winreg.HKEY_CLASSES_ROOT):
        '''
        Creates a key at the desired path.
        '''
        winreg.CreateKey(hive, path)

    def set_key_value(key_path: str, subkey_name: str, value: 'Value', hive=winreg.HKEY_CLASSES_ROOT):
        '''
        Changes the value of a subkey. Creates the subkey if it doesn't exist.
        '''

        registry_key = winreg.OpenKey(hive, key_path, 0,
                                      winreg.KEY_WRITE)
        winreg.SetValueEx(registry_key, subkey_name, 0, winreg.REG_SZ, value)
        winreg.CloseKey(registry_key)

    def list_keys(path: str, hive=winreg.HKEY_CLASSES_ROOT) -> 'List of keys':
        '''
        Returns a list of all the keys at a given registry path.
        '''

        open_key = winreg.OpenKey(hive, path)
        key_amt = winreg.QueryInfoKey(open_key)[0]
        keys = []

        for count in range(key_amt):
            subkey = winreg.EnumKey(open_key, count)
            keys.append(subkey)

        return keys

    def delete_key(path: str, hive=winreg.HKEY_CLASSES_ROOT):
        '''
        Deletes the desired key and all other subkeys at the given path.
        '''
        open_key = winreg.OpenKey(hive, path)
        subkeys = list_keys(path)

        if len(subkeys) > 0:
            for key in subkeys:
                delete_key(path + '\\' + key)
        winreg.DeleteKey(open_key, "")
except:
    print('Not linux')


# advanced_reg_config.py ----------------------------------------------------------------------------------------


# These are the paths in the registry that correlate to when the context menu is fired.
# For example, FILES is when a file is right clicked
CONTEXT_SHORTCUTS = {
    'FILES': '*\\shell',
    'DIRECTORY': 'Directory\\shell',
    'DIRECTORY_BACKGROUND': 'Directory\\Background\\shell',
    'DESKTOP_BACKGROUND': 'DesktopBackground\\shell',
    'DRIVE': 'Drive\\shell'
}

# Not used yet, but could be useful in the future
COMMAND_PRESETS = {
    'python': sys.executable,
    'pythonw': os.path.join(os.path.dirname(sys.executable), 'pythonw.exe')
}

COMMAND_VARS = {
    'FILENAME' : "' '.join(sys.argv[1:]) ",
    'DIR': 'os.getcwd()',
    'DIRECTORY': 'os.getcwd()',
    'PYTHONLOC' : 'sys.executable'
}

def context_registry_format(item: str) -> 'registry path to the desired type':
    '''
    Converts a verbose type into a registry path.

    For example, 'FILES' -> '*\\shell'
    '''
    item = item.upper()
    if '.' in item:
        return item.lower()
    return CONTEXT_SHORTCUTS[item]


def command_preset_format(item: str) -> 'Path to desired python type':
    '''
    Converts a python string to an executable location.

    For example, 'python' -> sys.executable
    '''
    return COMMAND_PRESETS[item.lower()]

def command_var_format(item: str):
    '''
    Converts a python string to a value for a command

    '''
    return COMMAND_VARS[item.upper()]

def create_file_select_command(func_name: str, func_file_name: str, func_dir_path: str, params: str) -> 'Registry valid string to call python function':
    '''
    Creates a registry valid command to link a context menu entry to a funtion, specifically for file selection(FILES, DIRECTORY, DRIVE).

    Requires the name of the function, the name of the file, and the path to the directory of the file.
    '''
    python_loc = sys.executable
    sys_section = f'''import sys; sys.path.insert(0, '{func_dir_path[2:]}')'''.replace(
        '\\', '/')
    file_section = f'import {func_file_name}'
    dir_path = """' '.join(sys.argv[1:]) """
    func_section = f'''{func_file_name}.{func_name}([{dir_path}],'{params}')'''
    python_portion = f'''"{python_loc}" -c "{sys_section}; {file_section}; {func_section}"'''
    full_command = '''{} \"%1\""'''.format(python_portion)

    return full_command


def create_directory_background_command(func_name: str, func_file_name: str, func_dir_path: str, params: str) -> 'Registry valid string to call python function':
    '''
    Creates a registry valid command to link a context menu entry to a funtion, specifically for backgrounds(DIRECTORY_BACKGROUND, DESKTOP_BACKGROUND).

    Requires the name of the function, the name of the file, and the path to the directory of the file.
    '''
    python_loc = sys.executable
    sys_section = f'''import sys; import os; sys.path.insert(0, '{func_dir_path[2:]}')'''.replace(
        '\\', '/')
    file_section = f'import {func_file_name}'
    dir_path = 'os.getcwd()'
    func_section = f'''{func_file_name}.{func_name}([{dir_path}],'{params}')'''
    full_command = f'''"{python_loc}" -c "{sys_section}; {file_section}; {func_section}"'''

    return full_command


def create_shell_command(command: str, command_vars: list) -> 'Shell command':
    '''
    Creates a shell command and replaces '?' with the command_vars list
    '''

    transformed_vars = ["' + " + command_var_format(item) + " + '" for item in command_vars]
    new_command = command.replace("?", '{}').format(*transformed_vars)
    python_section = '''import os; import sys; os.system('{}')'''.format(new_command)
    full_command = '"{}" -c "{}" \"%1\""'.format(sys.executable, python_section)
    return full_command



# windows_menus.py ----------------------------------------------------------------------------------------


# Used to create a Registry entry
class RegistryMenu:
    '''
    Class to convert the general menu from menus.py to a Windows-specific menu.
    '''

    def __init__(self, name: str, sub_items: list, type: str):
        '''
        Handled automatically by menus.py, but requires a name, all the sub items, and a type
        '''
        self.name = name
        self.sub_items = sub_items
        self.type = type.upper()
        self.path = context_registry_format(type)

    def create_menu(self, name: str, path: str) -> 'Path to shell key of new menu':
        '''
        Creates a menu with the given name and path.

        Used in the compile method.
        '''
        key_path = os.path.join(path, name)
        create_key(key_path)

        set_key_value(key_path, 'MUIVerb', name)
        set_key_value(key_path, 'subcommands', '')

        key_shell_path = os.path.join(key_path, 'shell')
        create_key(key_shell_path)

        return key_shell_path

    def create_command(self, name: str, path: str, command: str):
        '''
        Creates a key with a command subkey with the 'name' and 'command', at path 'path'.
        '''
        key_path = os.path.join(path, name)
        create_key(key_path)
        set_key_value(key_path, '', name)

        command_path = os.path.join(key_path, 'command')
        create_key(command_path)
        set_key_value(command_path, '', command)

    def compile(self, items: list = None, path: str = None):
        '''
        Used to create the meun. Recursively iterates through each element in the top level menu.
        '''
        if items == None:
            run_admin()
            items = self.sub_items
            path = self.create_menu(self.name, self.path)

        for item in items:
            if item.isMenu:
                # if the item is a menu
                submenu_path = self.create_menu(item.name, path)
                self.compile(items=item.sub_items, path=submenu_path)
            else:
                # Otherwise the item is  a command
                if item.command == None:
                    # If a Python function is defined
                    func_name, func_file_name, func_dir_path = item.get_method_info()
                    new_command = None
                    if self.type in ['DIRECTORY_BACKGROUND', 'DESKTOP_BACKGROUND']:
                        # If it requires a background command
                        new_command = create_directory_background_command(
                            func_name, func_file_name, func_dir_path, item.params)
                    else:
                        # If it requires a file command
                        new_command = create_file_select_command(
                            func_name, func_file_name, func_dir_path, item.params)
                    self.create_command(item.name, path, new_command)
                elif item.command_vars != None:
                    # If the item has to be ran from os.system

                    new_command = create_shell_command(item.command, item.command_vars)
                    self.create_command(item.name, path, new_command)
                else:
                    # The item is just a plain old command
                    self.create_command(item.name, path, item.command)


# Fast command class
# Everything is identical to either the RegistryMenu class or code in the menus file
class FastRegistryCommand:
    '''
    Fast command class.

    Everything is identical to either the RegistryMenu class or code in the menus file
    '''

    def __init__(self, name: str, type: str, command: str, python: 'function', params: str, command_vars: list):
        self.name = name
        self.type = type
        self.path = context_registry_format(type)
        self.command = command
        self.python = python
        self.params=params
        self.command_vars = command_vars

    def get_method_info(self):
        import inspect

        func_file_path = os.path.abspath(inspect.getfile(self.python))

        func_dir_path = os.path.dirname(func_file_path)
        func_name = self.python.__name__
        func_file_name = os.path.splitext(os.path.basename(func_file_path))[0]

        return (func_name, func_file_name, func_dir_path)

    def compile(self):
        run_admin()

        key_path = os.path.join(self.path, self.name)
        create_key(key_path)

        command_path = os.path.join(key_path, 'command')
        create_key(command_path)

        new_command = self.command

        if self.command == None:
            # If a python function is defined
            func_name, func_file_name, func_dir_path = self.get_method_info()
            if self.type in ['DIRECTORY_BACKGROUND', 'DESKTOP_BACKGROUND']:
                # If it requires a background selection
                new_command = create_directory_background_command(
                    func_name, func_file_name, func_dir_path, self.params)
            else:
                # If it requires a file selection
                new_command = create_file_select_command(
                    func_name, func_file_name, func_dir_path, self.params)
        elif self.command_vars != None:
            # If it has command_vars
            new_command = create_shell_command(self.command, self.command_vars)

        set_key_value(command_path, '', new_command)


# Testing section...

try:
    def remove_windows_menu(name: str, type: str):
        '''
        Removes a context menu from the windows registry.
        '''
        run_admin()
        menu_path = os.path.join(CONTEXT_SHORTCUTS[type], name)
        delete_key(menu_path)
except:
    pass
    # for testing



import inspect
import sys
import os
import platform

# Need to append all the python subdirectories because Python doesn't recognize them
sys.path.append(os.path.abspath(os.path.dirname(__file__)))


# Import the necessary library depending on the OS
if platform.system() == 'Linux':
    import linux_menus
if platform.system() == 'Windows':
    import windows_menus


class ContextMenu:
    '''
    The general menu class. This class generalizes the menus and eventually passes the correct values to the platform-specifically menus.
    '''

    def __init__(self, name: str, type: str = None):
        '''
        Only specify type if it's the root menu.
        '''

        self.name = name
        self.sub_items = []
        self.type = type
        self.isMenu = True  # Needed to avoid circular imports

    def add_items(self, items: list):
        '''
        Adds a list of items to the current menu.
        '''
        for item in items:
            self.sub_items.append(item)

    def compile(self):
        '''
        Recognizes the current platform and passes information to the respective menu. Creates the actual menu.
        '''
        if platform.system() == 'Linux':
            linux_menus.NautilusMenu(
                self.name, self.sub_items, self.type).compile()
        if platform.system() == 'Windows':
            windows_menus.RegistryMenu(
                self.name, self.sub_items, self.type).compile()


class ContextCommand:
    '''
    The general command class.

     A command is an executable entry in a context-menu, where menus hold other commands.

     Name = Name of the command
     Command = command to be ran from the shell
     python = function to be ran
     params = any other parameters to be passed
     command_vars = to help with the command
    '''

    def __init__(self, name: str, command: str = None, python: 'function' = None, params: str ='', command_vars: list = None):
        '''
        Do not specify both 'python' and 'command', either pass a python function or a command but not both.
        '''
        self.name = name
        self.command = command
        self.isMenu = False
        self.python = python
        self.params = params
        self.command_vars = command_vars

        if command != None and python != None:
            raise ValueError('both command and python cannot be defined')

    def get_platform_command(self):
        '''
        Will be used in future changes.
        '''
        return self.command[platform.system().lower()]

    def get_method_info(self) -> "('function name', 'function file name', 'path to function directory')":
        '''
        Extremely important for making shell commands to run python code.

        Returns a tuple.
        '''
        func_file_path = os.path.abspath(inspect.getfile(self.python))

        func_dir_path = os.path.dirname(func_file_path)
        func_name = self.python.__name__
        func_file_name = os.path.splitext(os.path.basename(func_file_path))[0]

        return (func_name, func_file_name, func_dir_path)


class FastCommand:
    '''
    Used for fast creation of a command. Good if you don't want to get too involved and just jump start a program.

    Extremely similar methods to other classes, only slightly modified. View the documentation of the above classes for info on these methods.
    '''

    def __init__(self, name: str, type: str, command: str = None, python: 'function' = None, params: str = '', command_vars: list = None):
        self.name = name
        self.type = type
        self.command = command
        self.python = python
        self.params = params
        self.command_vars = command_vars

        if command != None and python != None:
            raise ValueError('both command and python cannot be defined')

    def get_method_info(self):
        func_file_path = os.path.abspath(inspect.getfile(self.python))

        func_dir_path = os.path.dirname(func_file_path)
        func_name = self.python.__name__
        func_file_name = os.path.splitext(os.path.basename(func_file_path))[0]

        return (func_name, func_file_name, func_dir_path)

    def compile(self):
        if platform.system() == 'Linux':
            linux_menus.NautilusMenu(self.name, [ContextCommand(
                self.name, command=self.command, python=self.python, params=self.params, command_vars=self.command_vars)], self.type).compile()
        if platform.system() == 'Windows':
            windows_menus.FastRegistryCommand(
                self.name, self.type, self.command, self.python, self.params, self.command_vars).compile()

try:
    def removeMenu(name: str, type: str):
        '''
        Removes a menu/command entry from a context menu.

        Requires the name of the menu and type of the menu
        '''

        if platform.system() == 'Linux':
            linux_menus.remove_linux_menu(name)
        if platform.system() == 'Windows':
            windows_menus.remove_windows_menu(name, type)


except Exception as e:
    # For testing
    print(e)
    pass



# imports -------------------------------------------------
import os
from enum import Enum

# code_preset.py -------------------------------------


class ExistingCode(Enum):
    '''
    Preset values important for metaprogramming.
    '''

    CODE_HEAD = '''
import gi
import sys
import os

gi.require_version('Nautilus', '3.0')

from gi.repository import Nautilus, GObject

# -------------------------------------------- #

try:
\tfrom urllib import unquote
except ImportError:
\tfrom urllib.parse import unquote
    '''

    CLASS_TEMPLATE = '''
class ExampleMenuProvider(GObject.GObject, Nautilus.MenuProvider):
\tdef __init__(self):
\t\tpass
'''

    METHOD_HANDLER_TEMPLATE = '''
\tdef {}(self, menu, files):
\t\tfilenames = [unquote(subFile.get_uri()[7:]) for subFile in files]
\t\t{}.{}({}, "{}")

'''

    COMMAND_HANDLER_TEMPLATE = '''
\tdef {}(self, menu, files):
\t\tfilepath = [unquote(subFile.get_uri()[7:]) for subFile in files][0]
\t\tos.system('{}'{})

'''

    FILE_ITEMS = '\tdef get_file_items(self, window, files):'
    BACKGROUND_ITEMS = '\tdef get_background_items(self, window, files):'
    SUB_MENU = 'submenu{} = Nautilus.Menu()'
    MENU_ITEM = 'menuitem{} = Nautilus.MenuItem(name = "ExampleMenuProvider::{}", label="{}", tip = "{}", icon = "{}")'

# code_builder.py ----------------------------------


class CodeBuilder:
    '''
    The CodeBuilder class is used for generating the final python file for the Linux menus.
    '''

    def __init__(self, body_commands: list, script_dirs: list, funcs: list, imports: list, type: str):
        '''
        Pass the list of body_commands, the directories of all the scripts, the
        list of the function names, the list of the imports, and the type.
        '''
        self.body_commands = body_commands
        self.script_dirs = list(set(script_dirs))
        self.funcs = funcs
        self.imports = list(set(imports))
        self.type = type.upper()

    def build_script_dirs(self):
        '''
        Creates the header of necessary path configurations.

        Adds all the 'sys.path.appends' in order to immport the classes and functions.

        Handled automatically by compile.
        '''
        compiled_dirs = [f'sys.path.append("{x}")' for x in self.script_dirs]
        return '\n'.join(compiled_dirs)

    def build_imports(self):
        '''
        Creates the header of necessary imports.

        Handled automatically by compile.
        '''
        compiled_imports = [f'import {x}' for x in self.imports]
        return '\n'.join(compiled_imports)

    def compile(self):
        '''
        Creates the code file.
        '''
        code_head = ExistingCode.CODE_HEAD.value
        script_dirs_code = self.build_script_dirs()
        imports_code = self.build_imports()
        class_dec = ExistingCode.CLASS_TEMPLATE.value
        class_funcs = '\n\n'.join(self.funcs)
        class_type = ExistingCode.FILE_ITEMS.value
        if self.type in ['DIRECTORY_BACKGROUND', 'DESKTOP_BACKGROUND']:
            class_type = ExistingCode.BACKGROUND_ITEMS.value
        class_body = '\n'.join(map(lambda x: '\t\t' + x, self.body_commands))

        code_skeleton = '''
{}
{}
{}
{}
{}
{}
{}
    '''.format(code_head, script_dirs_code, imports_code, class_dec, class_funcs, class_type, class_body)

        return code_skeleton


COMMAND_VARS = {
    'FILENAME' : "filepath",
    'DIR': "os.getcwd()",
    'DIRECTORY': "os.getcwd()",
    'PYTHONLOC' : 'sys.executable'
}

def command_var_format(item: str):
    '''
    Converts a python string to a value for a command

    '''
    return COMMAND_VARS[item.upper()]


# code_builder.py ----------------------------------

# Not necessary, but helps simplify the code.
class Variable:
    '''
    Very simple class with no methods to help simplify the code.
    '''

    def __init__(self, name: str, code: str):
        self.name = name
        self.code = code


class NautilusMenu:

    # Constructor, automatically handeled by menus.py
    def __init__(self, name: str, sub_items: list, type: str):
        '''
        Items required are the name of the top menu, the sub items, and the type.
        '''
        self.name = name
        self.sub_items = sub_items
        self.type = type
        self.counter = 0

# Create all the necessary lists that will be used later on
        self.commands = []
        self.script_dirs = []
        self.funcs = []
        self.imports = []

# Methods to create action code
    def append_item(self, menu: str, item: str):
        '''
        Creates a necssary body_command.
        '''
        return "{}.append_item({})".format(menu, item)

    def set_submenu(self, item: str, menu: str):
        '''
        Creates a necssary body_command.
        '''
        return '{}.set_submenu({})'.format(item, menu)

    def connect(self, item: str, func: str):
        '''
        Creates a necssary body_command.
        '''
        return '{}.connect("activate", {}, files)'.format(item, func)

# Methods to create variable declarations

    def generate_menu(self):
        '''
        Generates a nautilus menu variable.
        '''
        base_menu = ExistingCode.SUB_MENU.value
        base_menu = base_menu.format(self.counter)
        self.counter += 1

        return Variable(base_menu.split(' = ')[0], base_menu)

    def generate_item(self, name: str):
        '''
        Generates a nautilus command variable.
        '''
        base_command = ExistingCode.MENU_ITEM.value
        formatted_item = base_command.format(self.counter, name, name, '', '')
        self.counter += 1

        return Variable(formatted_item.split(' = ')[0], formatted_item)

    def generate_python_func(self, class_origin: str, class_func: str, params: str):
        '''
        Generates a command attached to a python function
        '''
        func_name = 'method_handler{}'.format(self.counter)
        created_func = ExistingCode.METHOD_HANDLER_TEMPLATE.value.format(
            func_name, class_origin, class_func, 'filenames', params)

        self.counter += 1

        return Variable(f'self.{func_name}', created_func)

    def generate_command_func(self, command: str):
        '''
        Generates a command attached to a python function
        '''
        func_name = 'method_handler{}'.format(self.counter)
        created_func = ExistingCode.COMMAND_HANDLER_TEMPLATE.value.format(
            func_name, command, '')

        self.counter += 1

        return Variable(f'self.{func_name}', created_func)

    def generate_mod_command_func(self, command: str, command_vars: list):
        '''
        Generates a command attached to a python function that allows special variables.
        '''
        new_command = command.replace('?',  '{}')
        modified_vars = [command_var_format(item) for item in command_vars]
        final_str = ', '.join(modified_vars)
        func_name = 'method_handler{}'.format(self.counter)
        replace_func = """.format({})""".format(final_str)
        created_func = ExistingCode.COMMAND_HANDLER_TEMPLATE.value.format(
            func_name, new_command, replace_func)

        self.counter += 1

        return Variable(f'self.{func_name}', created_func)



# Other misc methods to help out


    def get_next_item(self):
        '''
        Very niche, required in other methods.
        '''
        val = self.generate_item('')
        self.counter -= 1

        return val.name


# Building the script body


    def build_script_body(self, name: str, items: list):
        '''
        Builds the body commands of the script.
        '''
        top_item = self.generate_item(name)
        top_menu = self.generate_menu()
        submenu_com = self.set_submenu(top_item.name, top_menu.name)
        self.commands.append(top_item.code)
        self.commands.append(top_menu.code)
        self.commands.append(submenu_com)

        for item in items:
            if item.isMenu:
                subsubmenu_con = self.append_item(
                    top_menu.name, self.get_next_item())
                self.build_script_body(item.name, item.sub_items)
                self.commands.append(subsubmenu_con)
            else:
                # if the item is a command
                formatted_command = self.generate_item(item.name)
                self.commands.append(formatted_command.code)

                connected_func = None

                if item.python != None:
                    # if there is a python function
                    item_info = item.get_method_info()
                    connected_func = self.generate_python_func(
                        item_info[1], item_info[0], item.params)
                    self.script_dirs.append(item_info[2])
                    self.imports.append(item_info[1])
                elif item.command_vars != None:
                    # if the command requries parameters
                    connected_func = self.generate_mod_command_func(item.command, item.command_vars)
                else:
                    # if the command is simply normal
                    connected_func = self.generate_command_func(item.command)
                    # connected_func = self.generate_func('os', 'system')

                self.funcs.append(connected_func.code)

                connected_command = self.connect(
                    formatted_command.name, connected_func.name)
                self.commands.append(connected_command)

                formatted_command = self.append_item(
                    top_menu.name, formatted_command.name)
                self.commands.append(formatted_command)

    def build_script(self):
        '''
        Finishes and returns the full code.
        '''
        self.build_script_body(self.name, self.sub_items)
        self.commands.append('return menuitem0,')
        full_code = CodeBuilder(
            self.commands, self.script_dirs, self.funcs, self.imports, self.type).compile()

        return full_code

    def create_path(self, path: str, dir: str):
        '''
        Creates a path to directory. Creates all sub-directories
        '''
        new_dir = os.path.join(path, dir)
        if not os.path.exists(new_dir):
            os.makedirs(new_dir)
        return new_dir

    def compile(self):
        '''
        Creates the code, creates a file, and moves it to the correct location.
        '''
        code = self.build_script()
        save_loc = os.path.join(os.path.expanduser('~'), '.local/share/')
        print(save_loc)
        save_loc = self.create_path(save_loc, 'nautilus-python')
        save_loc = self.create_path(save_loc, 'extensions')
        save_loc = os.path.join(save_loc, f'{self.name}.py')
        py_file = open(save_loc, 'w')
        py_file.write(code)
        py_file.close()

# Testing section...

try:
    def remove_linux_menu(name):
        save_loc = os.path.join(os.path.expanduser('~'), '.local/share/nautilus-python/extensions', name)
        try:
            os.remove(save_loc + '.py')
            os.remove(save_loc + '.pyc')
        except Exception as e:
            print(e)

except:
    pass



import pathlib
import setuptools

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setuptools.setup(
    name="context_menu",
    version="1.1.0",
    description="Library to create cross-platform native context menus.",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/saleguas/context_menu",
    author="Salvador Aleguas",
    author_email="salvador@aleguas.dev",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    packages=setuptools.find_packages(),
)
